/******************************************************************************
 * AudioManager.java - Let's make some noise.
 * $Id: AudioManager.java,v 1.6 2009/02/25 09:41:12 dick Exp $
 * 
 * BuckoFIBS - Backgammon by BuckoSoft
 * Copyright 2009 - Dick Balaska - BuckoSoft, Corp.
 * 
 * $Log: AudioManager.java,v $
 * Revision 1.6  2009/02/25 09:41:12  dick
 * Handle ATTENTION messages from FIBS when it is shutting down.
 *
 * Revision 1.5  2009/02/17 14:43:42  dick
 * Wrap debug with DEBUG.
 *
 * Revision 1.4  2009/02/16 06:56:11  dick
 * Audio works in a jar file now.
 *
 * Revision 1.3  2009/02/14 12:04:51  dick
 * BuckoFIBS is released under the GNU license.
 * Javadoc.
 *
 * Revision 1.2  2009/02/12 06:05:52  dick
 * Add Cue.CantMoveHere.
 *
 * Revision 1.1  2009/02/03 09:43:02  dick
 * Let's make some noise.
 *
 */

/* 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * The Original Code is BuckoFIBS, <http://www.buckosoft.com/BuckoFIBS/>.
 * The Initial Developer of the Original Code is Dick Balaska and BuckoSoft, Corp.
 * 
 */
package com.buckosoft.fibs.BuckoFIBS;

import java.awt.Component;
import java.net.URI;
import java.net.URL;
import java.util.LinkedList;

import javax.swing.JOptionPane;

import sun.audio.AudioPlayer;
import sun.audio.AudioStream;

/** Let's make some noise. <br>
 * Audio hack from <a href="http://www.javaworld.com/javaworld/javatips/jw-javatip24.html">
 * 	Java Tip 24: How to play audio in applications
 * </a><br>
 * This component does not work when launched from jnlp.<br>
 * It also 
 * @author Dick Balaska
 * @since 2009/02/02
 * @version $Revision: 1.6 $ <br> $Date: 2009/02/25 09:41:12 $
 * @see <a href="http://cvs.buckosoft.com/Projects/BuckoFIBS/BuckoFIBS/src/com/buckosoft/fibs/BuckoFIBS/AudioManager.java">cvs AudioManager.java</a>
 */
public class AudioManager {
	private final static boolean DEBUG = false;

	/** Define the Sound events that we can play
	 * @author Dick Balaska
	 * @since 2009/02/02
	 * @version $Revision: 1.6 $ <br> $Date: 2009/02/25 09:41:12 $
	 * @see <a href="http://cvs.buckosoft.com/Projects/BuckoFIBS/BuckoFIBS/src/com/buckosoft/fibs/BuckoFIBS/AudioManager.java">cvs AudioManager.java</a>
	 */
	public enum Cue {
		/** You have been invited to play a match with someone. */
		Invited,
		/** It's your turn to roll or double */
		RollOrDouble,
		/** It's your turn. */
		YourTurn,
		/** You pick up the dice and end your turn. */
		PickUpDice,
		/** A chat message has been displayed in the chat window. */
		ChatReceived,
		/** You tried to move a checker to an occupied space. */
		CantMoveHere,
		/** FIBS wants your attention, like before a shutdown */
		FibsAttention
		
	}

	private class CueAndFile {
		CueAndFile(Cue c, URI u, String s) {
			this.cue = c;
			this.uri = u;
			this.s = s;
		}
		Cue	cue;
		URI	uri;
		String s;
	}
	
	private LinkedList<CueAndFile>	list = new LinkedList<CueAndFile>();

	/** The default constructor.
	 * Don't do anything useful because we want to catch the exceptions via the initialize method.
	 */
	public AudioManager() {
	}
	
	/** Initialize the AudioManager.
	 * @param parent Unused.
	 */
	public void initialize(Component parent) {
		_init(parent, Cue.Invited,		"ringin");
		_init(parent, Cue.RollOrDouble,	"waiting");
		_init(parent, Cue.YourTurn,		"yourTurn");
		_init(parent, Cue.PickUpDice,	"pickUpDice");
		_init(parent, Cue.ChatReceived,	"chatReceived");
		_init(parent, Cue.CantMoveHere,	"failure");
		_init(parent, Cue.FibsAttention,"failure");
	}
	
	private	void _init(Component parent, Cue cue, String fname) {
		URL url;
		URI uri;
		String s = "/audio/" + fname + ".wav";
		url = getClass().getResource(s);
		if (url == null) {
			JOptionPane.showMessageDialog(parent, "Can't find audio file '" + s + "'",
					"Warning", JOptionPane.WARNING_MESSAGE);
			return;
		}
		try {
			uri = url.toURI();
		} catch (Exception ex) {
			ex.printStackTrace();
			JOptionPane.showMessageDialog(parent, "Can't load audio file '" + s + "'",
					"Warning", JOptionPane.WARNING_MESSAGE);
			return;
		}
		list.add(new CueAndFile(cue, uri, s));
	}

	/** Play this event
	 * @param cue The event to play
	 */
	public void play(Cue cue) {
		try {
			for (CueAndFile caf : list) {
				if (caf.cue == cue) {
					if (DEBUG)
						System.out.println("uri=" + caf.uri.toString());
					AudioStream as = new AudioStream(getClass().getResourceAsStream(caf.s));
					AudioPlayer.player.start(as);            
					return;
				}
			}
		} catch (Exception ex) {
			ex.printStackTrace();
		}
	}
}
