/******************************************************************************
 * Database.java - The API into the BuckoFIBS database. 
 * $Id: Database.java,v 1.3 2009/03/04 19:01:58 dick Exp $
 * 
 * BuckoFIBS - Backgammon by BuckoSoft
 * Copyright 2009 - Dick Balaska - BuckoSoft, Corp.
 * 
 * $Log: Database.java,v $
 * Revision 1.3  2009/03/04 19:01:58  dick
 * Add getFinishedMatches(pid).
 *
 * Revision 1.2  2009/02/21 18:00:01  dick
 * Add getAllRatingsByDate()
 *
 * Revision 1.1  2009/02/20 10:23:04  dick
 * The API into the BuckoFIBS database.
 *
 */

/* 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * The Original Code is BuckoFIBS, <http://www.buckosoft.com/BuckoFIBS/>.
 * The Initial Developer of the Original Code is Dick Balaska and BuckoSoft, Corp.
 */
package com.buckosoft.fibs.BuckoFIBS.db;

import java.util.List;

import com.buckosoft.fibs.domain.FinishedMatch;
import com.buckosoft.fibs.domain.Player;

/** The API into the BuckoFIBS database.
 * @author Dick Balaska
 * @since 2009/02/18
 * @version $Revision: 1.3 $ <br> $Date: 2009/03/04 19:01:58 $
 * @see <a href="http://cvs.buckosoft.com/Projects/BuckoFIBS/BuckoFIBS/src/com/buckosoft/fibs/BuckoFIBS/db/Database.java">cvs Database.java</a>
 */
public interface Database {

	/** Write this player to the database
	 * @param player The player to write.
	 */
	void	store(Player player);

	/** Find this player based on his id
	 * @param id The player id to query
	 * @return The Player with this id or null if not found
	 */
	Player	getPlayer(int id);

	/** Find this Player based on his name
	 * @param name The Player name to query
	 * @return The Player with this name or null if not found
	 */
	Player	getPlayer(String name);
	
	/** Store this FinishedMatch to the database
	 * @param finishedMatch the match we just finished
	 */
	void store(FinishedMatch finishedMatch);
	
	/** Return an array of your ratings ordered by date
	 * @return your ratings
	 */
	double[] getAllRatingsByDate();
	
	/** Update the opponent with the data that we have.
	 * This includes his local id and win/loss record.
	 * @param p The Player to update
	 */
	void updateOpponent(Player p);

	/** Get a List of matches that you have played against this player.
	 * @param pid The playerid to query.
	 * @return The List of FinishedMatches.  An empty List if no matches found.
	 */
	List<FinishedMatch>	getFinishedMatches(int pid);
}
