/******************************************************************************
 * Toolbar.java - The BuckoFIBS main toolbar
 * $Id: ToolBar.java,v 1.12 2009/03/04 19:05:03 dick Exp $
 * 
 * BuckoFIBS - Backgammon by BuckoSoft
 * Copyright 2008 - Dick Balaska - BuckoSoft, Corp.
 * 
 * $Log: ToolBar.java,v $
 * Revision 1.12  2009/03/04 19:05:03  dick
 * Javadoc.
 *
 * Revision 1.11  2009/02/21 17:59:05  dick
 * Add the RatingGraphPanel.
 *
 * Revision 1.10  2009/02/14 12:25:22  dick
 * Unused button becomes About button.
 *
 * Revision 1.9  2009/01/28 19:13:24  dick
 * Use the notes.png icon.
 *
 * Revision 1.8  2009/01/13 18:27:39  dick
 * Handle Ready To Play
 *
 * Revision 1.7  2009/01/09 07:16:51  dick
 * Add the Prefs4Messages button.
 *
 * Revision 1.6  2008/12/17 04:38:00  dick
 * Connect button work.
 *
 * Revision 1.5  2008/12/15 01:53:57  dick
 * Cleanup.
 *
 * Revision 1.4  2008/12/13 06:29:09  dick
 * Add ReadyToPlay and some funky icons.
 *
 * Revision 1.3  2008/12/11 08:49:26  dick
 * Add the tools (preferences) button.
 *
 * Revision 1.2  2008/03/30 05:44:12  dick
 * Execute a command when the connection button is clicked.
 *
 * Revision 1.1  2008/03/29 08:57:43  dick
 * BuckoFIBS skeleton checkin.
 *
 */

/* 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * The Original Code is BuckoFIBS, <http://www.buckosoft.com/BuckoFIBS/>.
 * The Initial Developer of the Original Code is Dick Balaska and BuckoSoft, Corp.
 * 
 */
package com.buckosoft.fibs.BuckoFIBS.gui;

import java.awt.Color;
import java.awt.Dimension;
import java.awt.GridBagLayout;

import javax.swing.ImageIcon;
import javax.swing.JButton;
import javax.swing.JCheckBox;
import javax.swing.JToolBar;

import com.buckosoft.fibs.BuckoFIBS.CommandDispatcher;

/** The BuckoFIBS main toolbar.
 * @author Dick Balaska
 * @since 2008/03/29
 * @version $Revision: 1.12 $ <br> $Date: 2009/03/04 19:05:03 $
 * @see <a href="http://cvs.buckosoft.com/Projects/BuckoFIBS/BuckoFIBS/src/com/buckosoft/fibs/BuckoFIBS/gui/ToolBar.java">cvs ToolBar.java</a>
 */
public class ToolBar extends JToolBar {
	private static final long serialVersionUID = 1L;

	private JButton jButtonConnect = null;

	private	CommandDispatcher commandDispatcher;  //  @jve:decl-index=0:

	private JButton jButtonTools = null;

	private JButton jButtonReadyToPlay = null;

	private JCheckBox jCheckBox = null;

	private	ImageIcon connectedIcon;  //  @jve:decl-index=0:
	private	ImageIcon notConnectedIcon;  //  @jve:decl-index=0:
	private	ImageIcon readyIcon;
	private ImageIcon notReadyIcon;
	
	private JButton jButtonMessages = null;

	private RatingGraphPanel ratingGraphPanel = null;

	/**
	 * Instantiate the ToolBar for BuckoFIBS 
	 * 
	 */
	public ToolBar() {
		super();
		initialize();
	}

	/** Set the reference to the command dispatcher
	 * @param commandDispatcher Our system CommandDispatcher
	 */
	public	void	setCommandDispatcher(CommandDispatcher commandDispatcher) {
		this.commandDispatcher = commandDispatcher;
	}

	public void setConnected(boolean b) {
		this.getJButtonConnect().setIcon(b ? connectedIcon : notConnectedIcon);
		this.getJButtonReadyToPlay().setEnabled(b);
	}

	private void handleConnectButton() {
		if (this.getJButtonConnect().getIcon() == connectedIcon)
			commandDispatcher.dispatch(CommandDispatcher.Command.DISCONNECT_FROM_NETWORK);
		else
			commandDispatcher.dispatch(CommandDispatcher.Command.SHOW_CONNECTION_DIALOG);
	}

	public void setReadyToPlay(boolean b) {
		this.getJButtonReadyToPlay().setIcon(b? readyIcon : notReadyIcon);
	}
	/**
	 * This method initializes this
	 * 
	 */
	private void initialize() {
		notConnectedIcon = new ImageIcon(getClass().getResource("/g/connectTelnet.png"));
		connectedIcon = new ImageIcon(getClass().getResource("/g/telnet.png"));
		readyIcon = new ImageIcon(getClass().getResource("/g/accept32.png"));
		notReadyIcon = new ImageIcon(getClass().getResource("/g/pause32.png"));

		this.add(getJButtonConnect());
		this.add(getJButtonTools());
		this.add(getJButtonMessages());
		this.add(getJButtonReadyToPlay());
        this.add(new JToolBar.Separator());
		this.add(getJCheckBox());
        this.add(new JToolBar.Separator());
        this.add(new JToolBar.Separator());
		this.add(getRatingGraphPanel());
	}
	
	/**
	 * This method initializes jButtonUp
	 * 	
	 * @return javax.swing.JButton	
	 */
	public JButton getJButtonConnect() {
		if (jButtonConnect == null) {
			jButtonConnect = new JButton();
			jButtonConnect.setIcon(new ImageIcon(getClass().getResource("/g/connectTelnet.png")));
			jButtonConnect.setMnemonic(java.awt.event.KeyEvent.VK_U);
			jButtonConnect.setPreferredSize(new Dimension(44, 44));
			jButtonConnect.setToolTipText("Connect to the Server");
			jButtonConnect.addActionListener(new java.awt.event.ActionListener() {
				public void actionPerformed(java.awt.event.ActionEvent e) {
					handleConnectButton();
				}
			});
		}
		return jButtonConnect;
	}

	/**
	 * This method initializes jButtonTools	
	 * 	
	 * @return javax.swing.JButton	
	 */
	private JButton getJButtonTools() {
		if (jButtonTools == null) {
			jButtonTools = new JButton();
			jButtonTools.setIcon(new ImageIcon(getClass().getResource("/g/tools.gif")));
			jButtonTools.setToolTipText("Configure options");
			jButtonTools.addActionListener(new java.awt.event.ActionListener() {
				public void actionPerformed(java.awt.event.ActionEvent e) {
					commandDispatcher.dispatch(CommandDispatcher.Command.SHOW_PREFERENCES_DIALOG);
				}
			});
		}
		return jButtonTools;
	}

	/**
	 * This method initializes jButtonReadyToPlay	
	 * 	
	 * @return javax.swing.JButton	
	 */
	private JButton getJButtonReadyToPlay() {
		if (jButtonReadyToPlay == null) {
			jButtonReadyToPlay = new JButton();
			jButtonReadyToPlay.setIcon(notReadyIcon);
			jButtonReadyToPlay.setToolTipText("Toggle \"Ready to play\"");
			jButtonReadyToPlay.addActionListener(new java.awt.event.ActionListener() {
				public void actionPerformed(java.awt.event.ActionEvent e) {
					commandDispatcher.dispatch(CommandDispatcher.Command.TOGGLE_READY_TO_PLAY);
				}
			});
		}
		return jButtonReadyToPlay;
	}

	/**
	 * This method initializes jCheckBox	
	 * 	
	 * @return javax.swing.JCheckBox	
	 */
	private JCheckBox getJCheckBox() {
		if (jCheckBox == null) {
			jCheckBox = new JCheckBox();
			jCheckBox.setIcon(new ImageIcon(getClass().getResource("/g/choo.png")));
			jCheckBox.setToolTipText("Display the about box");
			jCheckBox.setPressedIcon(new ImageIcon(getClass().getResource("/g/choo1.png")));
			jCheckBox.addActionListener(new java.awt.event.ActionListener() {
				public void actionPerformed(java.awt.event.ActionEvent e) {
					commandDispatcher.dispatch(CommandDispatcher.Command.SHOW_ABOUT_DIALOG);
				}
			});
		}
		return jCheckBox;
	}

	/**
	 * This method initializes jButtonMessages	
	 * 	
	 * @return javax.swing.JButton	
	 */
	private JButton getJButtonMessages() {
		if (jButtonMessages == null) {
			jButtonMessages = new JButton();
			jButtonMessages.setIcon(new ImageIcon(getClass().getResource("/g/notes.png")));
			jButtonMessages.setToolTipText("Configure message routing and display");
			jButtonMessages.addActionListener(new java.awt.event.ActionListener() {
				public void actionPerformed(java.awt.event.ActionEvent e) {
					commandDispatcher.dispatch(CommandDispatcher.Command.SHOW_PREFS4MSGS_DIALOG);
				}
			});
		}
		return jButtonMessages;
	}

	/**
	 * This method initializes jPanelRating	
	 * 	
	 * @return javax.swing.JPanel	
	 */
	public RatingGraphPanel getRatingGraphPanel() {
		if (ratingGraphPanel == null) {
			ratingGraphPanel = new RatingGraphPanel();
			ratingGraphPanel.setLayout(new GridBagLayout());
			ratingGraphPanel.setPreferredSize(new Dimension(100, 40));
			ratingGraphPanel.setBackground(Color.black);
		}
		return ratingGraphPanel;
	}
}
