/******************************************************************************
 * MatchStatusPanel.java - Draw the Match statistics at the top of the board.
 * $Id: MatchStatusPanel.java,v 1.3 2009/02/14 15:27:42 dick Exp $
 * 
 * BuckoFIBS - Backgammon by BuckoSoft
 * Copyright 2009 - Dick Balaska - BuckoSoft, Corp.
 * 
 * $Log: MatchStatusPanel.java,v $
 * Revision 1.3  2009/02/14 15:27:42  dick
 * BuckoFIBS is released under the GNU license.
 *
 * Revision 1.2  2009/01/29 08:27:22  dick
 * Draw the correct player in yellow.
 *
 * Revision 1.1  2009/01/28 19:37:28  dick
 * package com.buckosoft.fibs.gui.board becomes com.buckosoft.fibs.BuckoFIBS.gui.board.
 *
 * Revision 1.3  2009/01/10 05:07:29  dick
 * Put the correct data in the correct place.
 * Add pipCount handling.
 *
 * Revision 1.2  2009/01/08 18:33:29  dick
 * Fleshing out functionality.
 *
 * Revision 1.1  2009/01/08 01:33:35  dick
 * Draw the Match statistics at the top of the board.
 */

/* 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * The Original Code is BuckoFIBS, <http://www.buckosoft.com/BuckoFIBS/>.
 * The Initial Developer of the Original Code is Dick Balaska and BuckoSoft, Corp.
 * 
 */
package com.buckosoft.fibs.BuckoFIBS.gui.board;

import javax.swing.JPanel;
import javax.swing.JLabel;

import com.buckosoft.fibs.board.Board;

import java.awt.GridBagLayout;
import java.awt.GridBagConstraints;
import java.awt.Insets;
import java.awt.Color;
import java.awt.Dimension;
import java.awt.Font;

/** Draw the Match statistics at the top of the board.
 * @author Dick Balaska
 * @since 2009/01/06
 * @version $Revision: 1.3 $ <br> $Date: 2009/02/14 15:27:42 $
 * @see <a href="http://cvs.buckosoft.com/Projects/BuckoFIBS/BuckoFIBS/src/com/buckosoft/fibs/BuckoFIBS/gui/board/MatchStatusPanel.java">cvs MatchStatusPanel.java</a>
 */
public class MatchStatusPanel extends JPanel {
	private static final long serialVersionUID = 1L;

	private	Board	board = null;  //  @jve:decl-index=0:

	private JLabel player0Name = null;
	private JLabel player1Name = null;

	private JLabel player0MatchScore = null;
	private JLabel player1MatchScore = null;

	private JLabel player0PipCount = null;
	private JLabel player1PipCount = null;

	private JLabel pipDifference = null;

	private JLabel matchLength = null;

	private JLabel jLabelBuckoFIBS = null;

	/** Crate and initialize a MatchStatusPanel
	 */
	public MatchStatusPanel() {
		super();
		initialize();
	}

	/** Set the reference to our Board
	 * @param board the board to set
	 */
	public void setBoard(Board board) {
		this.board = board;
	}

	/** Update the widgets based on changes to the board
	 */
	public void updateStatus() {
		if (board != null) {
			player0Name.setText(board.getPlayerName()[0]);
			player1Name.setText(board.getPlayerName()[1]);
			this.matchLength.setText("ML: " + board.getMatchLength());
			this.player0MatchScore.setText("" + board.getMatchScore()[0]);
			this.player1MatchScore.setText("" + board.getMatchScore()[1]);
			Color player0Color = Color.white;
			Color player1Color = Color.white;
			if (board.getWhosTurn()*board.getXO() == 1)
				player0Color = Color.yellow;
			else if (board.getWhosTurn()*board.getXO() == -1)
				player1Color = Color.yellow;
			player0Name.setForeground(player0Color);
			player1Name.setForeground(player1Color);
			
			int pp[] = board.getPipCount();
			this.player0PipCount.setText("" + pp[0]);
			this.player1PipCount.setText("" + pp[1]);
			int diff = pp[1] - pp[0];
			Color c = Color.yellow;
			if (diff > 0)
				c = Color.green;
			if (diff < 0)
				c = Color.red;
			this.pipDifference.setText("" + diff);
			this.pipDifference.setForeground(c);
		}
	}

	/**
	 * This method initializes this
	 * 
	 */
	private void initialize() {
        GridBagConstraints gridBagConstraints8 = new GridBagConstraints();
        gridBagConstraints8.gridx = 5;
        gridBagConstraints8.gridy = 1;
        jLabelBuckoFIBS = new JLabel();
        jLabelBuckoFIBS.setText("BuckoFIBS");
        jLabelBuckoFIBS.setFont(new Font("Dialog", Font.ITALIC, 10));
        jLabelBuckoFIBS.setForeground(Color.green);
        GridBagConstraints gridBagConstraints7 = new GridBagConstraints();
        gridBagConstraints7.gridx = 5;
        gridBagConstraints7.anchor = GridBagConstraints.EAST;
        gridBagConstraints7.gridy = 0;
        matchLength = new JLabel();
        matchLength.setText("ML: 0");
        matchLength.setForeground(Color.white);
        GridBagConstraints gridBagConstraints6 = new GridBagConstraints();
        gridBagConstraints6.gridx = 4;
        gridBagConstraints6.gridheight = 2;
        gridBagConstraints6.weightx = 4.0;
        gridBagConstraints6.fill = GridBagConstraints.HORIZONTAL;
        gridBagConstraints6.anchor = GridBagConstraints.WEST;
        gridBagConstraints6.insets = new Insets(0, 10, 0, 0);
        gridBagConstraints6.gridy = 0;
        pipDifference = new JLabel();
        pipDifference.setText("0");
        pipDifference.setForeground(Color.yellow);
        GridBagConstraints gridBagConstraints5 = new GridBagConstraints();
        gridBagConstraints5.gridx = 3;
        gridBagConstraints5.anchor = GridBagConstraints.EAST;
        gridBagConstraints5.weightx = 1.0;
        gridBagConstraints5.gridy = 0;
        player1PipCount = new JLabel();
        player1PipCount.setText("0");
        player1PipCount.setForeground(Color.white);
        GridBagConstraints gridBagConstraints4 = new GridBagConstraints();
        gridBagConstraints4.gridx = 3;
        gridBagConstraints4.weightx = 1.0;
        gridBagConstraints4.anchor = GridBagConstraints.EAST;
        gridBagConstraints4.gridy = 1;
        player0PipCount = new JLabel();
        player0PipCount.setText("0");
        player0PipCount.setForeground(Color.white);
        GridBagConstraints gridBagConstraints3 = new GridBagConstraints();
        gridBagConstraints3.gridx = 1;
        gridBagConstraints3.weightx = 1.0;
        gridBagConstraints3.anchor = GridBagConstraints.WEST;
        gridBagConstraints3.gridy = 0;
        player1MatchScore = new JLabel();
        player1MatchScore.setText("0");
        player1MatchScore.setForeground(Color.white);
        GridBagConstraints gridBagConstraints2 = new GridBagConstraints();
        gridBagConstraints2.gridx = 1;
        gridBagConstraints2.weightx = 1.0;
        gridBagConstraints2.anchor = GridBagConstraints.WEST;
        gridBagConstraints2.insets = new Insets(0, 0, 0, 0);
        gridBagConstraints2.gridy = 1;
        player0MatchScore = new JLabel();
        player0MatchScore.setText("0");
        player0MatchScore.setForeground(Color.white);
        GridBagConstraints gridBagConstraints1 = new GridBagConstraints();
        gridBagConstraints1.insets = new Insets(1, 1, 1, 1);
        gridBagConstraints1.gridy = 1;
        gridBagConstraints1.anchor = GridBagConstraints.WEST;
        gridBagConstraints1.weightx = 1.0;
        gridBagConstraints1.gridx = 0;
        GridBagConstraints gridBagConstraints = new GridBagConstraints();
        gridBagConstraints.insets = new Insets(1, 1, 1, 1);
        gridBagConstraints.gridy = 0;
        gridBagConstraints.anchor = GridBagConstraints.WEST;
        gridBagConstraints.fill = GridBagConstraints.NONE;
        gridBagConstraints.weightx = 1.0;
        gridBagConstraints.gridx = 0;
        this.setLayout(new GridBagLayout());
        this.setBackground(Color.darkGray);
        this.setSize(new Dimension(450, 32));
        this.setPreferredSize(new Dimension(450, 36));
        this.setForeground(Color.white);
        player1Name = new JLabel();
        player1Name.setText("Player1");
        player1Name.setForeground(Color.white);
        player0Name = new JLabel();
        player0Name.setText("Player0");
        player0Name.setForeground(Color.white);
        this.add(player0Name, gridBagConstraints1);
        this.add(player1Name, gridBagConstraints);
        this.add(player0MatchScore, gridBagConstraints2);
        this.add(player1MatchScore, gridBagConstraints3);
        this.add(player0PipCount, gridBagConstraints4);
        this.add(player1PipCount, gridBagConstraints5);
        this.add(pipDifference, gridBagConstraints6);
        this.add(matchLength, gridBagConstraints7);
        this.add(jLabelBuckoFIBS, gridBagConstraints8);
	}
}  //  @jve:decl-index=0:visual-constraint="10,10"
